package net.user1.reactor.chat {
  import net.user1.reactor.Client;
  import net.user1.reactor.CustomClient;
  import net.user1.reactor.UserAccount;
  
  /**
   * A custom Reactor client class representing chat clients in ReactorGUI
   * chat controls.
   * 
   * @since ReactorGUI 1.0.0
   */  
  public class ChatClient extends CustomClient {
//==============================================================================
// Constructor
//==============================================================================
    
    /**
     * Returns the client's user ID, or if no user ID has been set, returns the
     * string: "User" plus the client's ID (e.g., "User24").
     * 
     * @since ReactorGUI 1.0.0
     */ 
    public function getUserName ():String {
      var account:UserAccount = getAccount();
      if (account) {
        return account.getUserID();
      } else {
        return "User" + getClientID();
      }
    }  
    
    /**
     * Sends this client a private chat message.
     * 
     * @param message The message text (e.g., "How old are you?").
     * 
     * @since ReactorGUI 1.0.0
     */ 
    public function sendPrivateMessage (message:String):void {
      sendMessage(ChatMessages.PRIVATE_CHAT, message);
    }
  }
}