package net.user1.reactor.motion {
  import flash.geom.Point;
  
  /**
   * A list of Point objects that represent a motion path. Includes 
   * utilities to serialize and deserialize the list of positions for
   * transmission between users across a network. To broadcast a PositionList
   * to another user, use the PositionBroadcaster. To broadcast mouse coordinates
   * to another user, use the PointerPositionBroadcaster.
   * 
   * @since ReactorGUI 1.0.0
   * 
   * @see PositionBroadcaster
   * @see PointerPositionBroadcaster
   */  
  public class PositionList {
// =============================================================================    
//  VARIABLES
// =============================================================================    
    /**
     * The string used to separate positions in a serialized position list.
     * 
     * @since ReactorGUI 1.0.0
     */    
    public static var RECORD_SEPARATOR:String = "^";
    
    private var positions:Array;
    
// =============================================================================    
//  CONSTRUCTOR
// =============================================================================    
    public function PositionList () {
      positions = new Array();
    }
    
// =============================================================================    
//  POSITION MANAGMENT
// =============================================================================    
    public function addPosition (position:Point):void {
      positions.push(position);
    }

    public function addPositions (newPositions:PositionList):void {
      // Add the new positions to the list
      var numNewPositions:int = newPositions.length;
      for (var i:int = 0; i < numNewPositions; i++) {
        positions.push(newPositions.getPositionAt(i));
      }
    }
    
    public function getPositionAt (index:int):Point {
      return positions[index];
    }
    
    public function shift ():Point {
      return positions.shift();
    }
    
    public function clear ():void {
      positions = [];
    }
    
    public function get length ():int {
      return positions.length;
    }
    
// =============================================================================    
//  SERIALIZATION
// =============================================================================    
    public function serialize ():String {
      var posStrings:Array = [];
      
      for each (var position:Point in positions) {
        posStrings.push(position.x 
                        + PositionList.RECORD_SEPARATOR
                        + position.y);
      }

      return posStrings.join(PositionList.RECORD_SEPARATOR 
                             + PositionList.RECORD_SEPARATOR);
    }
    
// =============================================================================    
//  DESERIALIZATION
// =============================================================================    
    public function deserialize (positionListString:String):void {
      var posStrings:Array = positionListString.split(PositionList.RECORD_SEPARATOR 
                                                      + PositionList.RECORD_SEPARATOR);
      var position:Array;
      
      positions = new Array();
      for each (var positionString:String in posStrings) {
        position = positionString.split(PositionList.RECORD_SEPARATOR);
        positions.push(new Point(position[0], position[1]));
      }
    }
  }
}