package net.user1.reactor.ui {
  import flash.events.Event;
  
  /**  
   * AvatarPaneEvent is a simple data class used to pass information from 
   * an AvatarPane object to registered event-listeners when
   * an AvatarPane event occurs. 
   * 
   * The AvatarPaneEvent class also defines constants representing the 
   * available AvatarPaneEvent events.
   * 
   * Since 
   * ReactorGUI 1.0.0
   */
  public class AvatarPaneEvent extends Event {
    /**
     * An event triggered when an AvatarPane adds an Avatar object.
     * 
     * Since 
     * ReactorGUI 1.0.0
     */
    public static const ADD_AVATAR:String    = "ADD_AVATAR";
    
    /**
     * An event triggered when an AvatarPane removes an Avatar object.
     * 
     * Since 
     * ReactorGUI 1.0.0
     */
    public static const REMOVE_AVATAR:String = "REMOVE_AVATAR";

    private var avatar:Avatar;
    
    public function AvatarPaneEvent(type:String, 
                                    bubbles:Boolean=false, 
                                    cancelable:Boolean=false,
                                    avatar:Avatar = null) {
      super(type, bubbles, cancelable);
      this.avatar     = avatar;
    }
    
    /**
     * Returns the Avatar object that was added or removed to the target
     * AvatarPane.
     * 
     * Since 
     * ReactorGUI 1.0.0
     */
    public function getAvatar ():Avatar {
      return avatar;
    }
    
    public override function clone():Event {
      return new AvatarPaneEvent(type, bubbles, cancelable, avatar);
    }

    public override function toString ():String {
      return formatToString("AvatarPaneEvent", "type", "bubbles",
                            "cancelable", "eventPhase");
    } 
  }
}