package net.user1.reactor.ui {
  import flash.events.Event;
  import flash.events.MouseEvent;
  import flash.events.TextEvent;
  
  import mx.containers.HBox;
  import mx.controls.Alert;
  import mx.controls.Label;
  import mx.controls.TextInput;
  import mx.events.CloseEvent;
  import mx.formatters.SwitchSymbolFormatter;
  
  import net.user1.reactor.ClientManager;
  import net.user1.reactor.ClientManagerEvent;
  import net.user1.reactor.Status;

  public class BanAddressPane extends BanBase {
    protected var _clientManager:ClientManager;
    protected var addressBox:HBox;
    protected var addressLabel:Label;
    protected var addressInput:TextInput;
    protected var statusLabel:Label;
    
    public function BanAddressPane () {
    }
    
// =============================================================================
// UI MANAGEMENT
// =============================================================================
    
    override protected function createChildren ():void {
      if (addressInput == null) {
        addressBox = new HBox(); 
        addressBox.percentWidth = 100;
        
        addressLabel = new Label();
        addressLabel.text = "Address: ";
        addressLabel.width = 120;
        addressLabel.setStyle("textAlign", "right");
        
        addressInput = new TextInput();
        addressInput.percentWidth = 100;
        addressInput.addEventListener(Event.CHANGE, addressChangeListener);

        addressBox.addChild(addressLabel);
        addressBox.addChild(addressInput);
        
        addChild(addressBox);
        
        super.createChildren();
        
        statusLabel = new Label();
        statusLabel.percentWidth = 100;
        statusLabel.setStyle("textAlign", "center");
        statusLabel.setStyle("color", "0xAA0000");
        
        addChild(statusLabel);
      }
      disable();
    }
    
    public function enable ():void {
      row1.enabled = true;
      row2.enabled = true;
      row3.enabled = true;
    }
    
    public function disable ():void {
      row1.enabled = false;
      row2.enabled = false;
      row3.enabled = false;
    }
    
    public function getAddress ():String {
      return addressInput.text;
    }
    
    /**
     * Assigns input focus to the "Address" field.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function focusUserID ():void {
      addressInput.setFocus();
    }    
    
// =============================================================================
// DEPENDENCIES
// =============================================================================
    
    /**
     * Sets the client reference.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function set clientManager (clientManager:ClientManager):void {
      _clientManager = clientManager;
      _clientManager.addEventListener(ClientManagerEvent.BAN_RESULT, banResultListener);
    }
    
    /**
     * Returns the client reference.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function get clientManager ():ClientManager {
      return _clientManager;
    }
    
// =============================================================================
// CLIENT MANAGER LISTENERS
// =============================================================================
    
    public function banResultListener (e:ClientManagerEvent):void {
      if (e.getStatus() == Status.SUCCESS) {
        dispatchEvent(new Event(Event.COMPLETE));
      } else {
        switch (e.getStatus()) {
          case Status.ALREADY_BANNED:
          statusLabel.text = "The address " + e.getAddress() + " is already banned.";
          break;
          
          case Status.ERROR:
          statusLabel.text = "Server error. Could not ban address: " + e.getAddress();
          break;
        }
      }
      banButton.enabled = true;
    }
    
    
// =============================================================================
// UI LISTENERS
// =============================================================================
    
    override public function banClickListener (e:MouseEvent):void {
      var reason:String = reasonTextInput.text == "" ? "Banned via Union Admin" : reasonTextInput.text;
      var duration:int = foreverCheckbox.selected 
                         ? int.MAX_VALUE 
                         : durationCombo.selectedItem.data * durationUnitsCombo.selectedItem.data;
      
      _clientManager.ban(addressInput.text, duration, reason);
      banButton.enabled = false;
    }
  
    public function addressChangeListener (e:Event):void {
      if (addressInput.text == "") {
        disable();
      } else {
        enable();
      }
      dispatchEvent(new Event(Event.CHANGE));
    }
    
//==============================================================================
// DISPOSAL
//==============================================================================
    
    /**
     * Disposes of the resources used by this object, preparing it for garbage
     * collection.
     * 
     * @since ReactorGUI 1.0.0
     */    
    public function dispose ():void {
      _clientManager = null;
    }
  }
}