package net.user1.reactor.ui {
  import flash.events.Event;
  
  import mx.containers.TitleWindow;
  import mx.events.CloseEvent;
  import mx.managers.PopUpManager;
  
  import net.user1.reactor.AccountManager;
  import net.user1.reactor.AccountManagerEvent;
  import net.user1.reactor.ClientManager;
  import net.user1.reactor.IClient;
  
  /**
   * A popup window containing a ban-address interface.
   * 
   * @since ReactorGUI 1.0.0
   * 
   * @see RegisterPane
   */
  public class BanAddressWindow extends TitleWindow {
//==============================================================================
// VARIABLES
//==============================================================================
    protected var banAddressPane:BanAddressPane;
    
//==============================================================================
// CONSTRUCTOR
//==============================================================================
    /**
     * Constructor
     */
    public function BanAddressWindow () {
      buildUI();
      showCloseButton = true;
      addEventListener(CloseEvent.CLOSE, closeClickListener);
      addEventListener(Event.ADDED_TO_STAGE, addedToStageListener);
      setStyle("borderAlpha", .9);
    }
    
//==============================================================================
// UI CREATION
//==============================================================================
    
    protected function buildUI ():void {
      banAddressPane = new BanAddressPane();
      banAddressPane.addEventListener(Event.CHANGE, addressChangeListener);
      banAddressPane.addEventListener(Event.COMPLETE, banCompleteListener);
      addChild(banAddressPane);
      this.width = 450;
      this.height = 190;
      title = "Ban Address"
    }
    
//==============================================================================
// DEPENDENCIES
//==============================================================================
    
    /**
     * @private
     */    
    public function set clientManager (value:ClientManager):void {
      banAddressPane.clientManager = value;
    }

    /**
     * The AccountManager object used to perform account registration attempts.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function get clientManager ():ClientManager {
      return banAddressPane.clientManager;
    }
    
//==============================================================================
// UI CONTROL
//==============================================================================
    
    public function close ():void {
      dispose();
      PopUpManager.removePopUp(this);
    }
    
//==============================================================================
// UI LISTENERS
//==============================================================================
    
    public function closeClickListener (e:CloseEvent):void {
      close();
    }
    
    public function addressChangeListener (e:Event):void {
      var address:String = banAddressPane.getAddress();
      title = "Ban Address" + (address == "" ? "" : ": " + address);
    }
    
    public function banCompleteListener (e:Event):void {
      close();
    }
    
    public function addedToStageListener (e:Event):void {
      banAddressPane.focusUserID();
    }
    
//==============================================================================
// DISPOSAL
//==============================================================================
    
    /**
     * Disposes of the resources used by this object, preparing it for garbage
     * collection.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function dispose ():void {
      banAddressPane.dispose();
      removeEventListener(Event.ADDED_TO_STAGE, addedToStageListener);
    }
  }
}