package net.user1.reactor.ui {
  import flash.events.MouseEvent;
  
  import mx.collections.ArrayCollection;
  import mx.containers.HBox;
  import mx.containers.VBox;
  import mx.controls.Button;
  import mx.controls.CheckBox;
  import mx.controls.ComboBox;
  import mx.controls.Label;
  import mx.controls.TextInput;
  
  public class BanBase extends VBox {
    protected var row1:HBox;
    protected var row2:HBox;
    protected var row3:HBox;
    
    protected var durationLabel:Label;
    protected var durationCombo:ComboBox;
    protected var durationUnitsCombo:ComboBox;
    protected var foreverCheckbox:CheckBox;
    
    protected var reasonLabel:Label;
    protected var reasonTextInput:TextInput;
    
    protected var durationValuesProvider:ArrayCollection;
    protected var durationUnitsProvider:ArrayCollection;
    
    protected var banButton:Button;
    
// =============================================================================
// CONSTRUCTOR
// =============================================================================
    
    public function BanBase () {
      durationValuesProvider = new ArrayCollection();
      durationUnitsProvider = new ArrayCollection();
      percentWidth = 100;
      percentHeight = 100;
      setStyle("verticalAlign", "middle");
      setStyle("horizontalAlign", "center");
      
      populateProviders();
    }
    
// =============================================================================
// DATA PROVIDER INITIALIZATION
// =============================================================================
    
    protected function populateProviders ():void {
      for (var i:int = 1; i <= 1000; i++) {
        durationValuesProvider.addItem({label:(i).toString(), data:i});
      }
      
      durationUnitsProvider.addItem({label:"second(s)", data:1}); 
      durationUnitsProvider.addItem({label:"minute(s)", data:60});
      durationUnitsProvider.addItem({label:"hour(s)",   data:3600}); 
      durationUnitsProvider.addItem({label:"day(s)",    data:86400}); 
    }
    
// =============================================================================
// UI MANAGEMENT
// =============================================================================
    
    override protected function createChildren ():void {
      super.createChildren();
      
      if (durationCombo == null) {
        durationLabel = new Label();
        durationLabel.text = "Duration: ";
        durationLabel.width = 120;
        durationLabel.setStyle("textAlign", "right");
        
        durationCombo = new ComboBox();
        durationCombo.dataProvider = durationValuesProvider;
        durationCombo.selectedIndex = 23;
        
        durationUnitsCombo = new ComboBox();
        durationUnitsCombo.dataProvider = durationUnitsProvider;
        durationUnitsCombo.selectedIndex = 2;
        
        foreverCheckbox = new CheckBox();
        foreverCheckbox.label = "Forever";
        foreverCheckbox.addEventListener(MouseEvent.CLICK, foreverCheckboxClickListener);
        
        reasonLabel = new Label();
        reasonLabel.text = "Reason (optional): ";
        reasonLabel.width = 120;
        reasonLabel.setStyle("textAlign", "right");
        
        reasonTextInput = new TextInput();
        reasonTextInput.percentWidth = 100;
        
        banButton = new Button();
        banButton.label = "Ban";
        banButton.addEventListener(MouseEvent.CLICK, banClickListener);
        
        row1 = new HBox();
        row1.percentWidth = 97;
        
        row2 = new HBox();
        row2.percentWidth = 97;
        
        row3 = new HBox();
        row3.percentWidth = 97;
        row3.setStyle("horizontalAlign", "right");
        
        row1.addChild(durationLabel);
        row1.addChild(durationCombo);
        row1.addChild(durationUnitsCombo);
        row1.addChild(foreverCheckbox);
        
        row2.addChild(reasonLabel);
        row2.addChild(reasonTextInput);
        
        row3.addChild(banButton);
        
        addChild(row1);
        addChild(row2);
        addChild(row3);
      }
    }
    
// =============================================================================
// UI LISTENERS
// =============================================================================
    
    public function banClickListener (e:MouseEvent):void {
    }
    
    public function foreverCheckboxClickListener (e:MouseEvent):void {
      durationCombo.enabled = !foreverCheckbox.selected;
      durationUnitsCombo.enabled = !foreverCheckbox.selected;
    }
  }
}