package net.user1.reactor.ui {
  import mx.containers.TitleWindow;
  import mx.events.CloseEvent;
  import mx.managers.PopUpManager;
  
  import net.user1.reactor.IClient;
  
  /**
   * A popup window containing a ban-client interface.
   * 
   * @since ReactorGUI 1.0.0
   * 
   * @see RegisterPane
   */
  public class BanClientWindow extends TitleWindow {
//==============================================================================
// VARIABLES
//==============================================================================
    protected var banClientPane:BanClientPane;
    
//==============================================================================
// CONSTRUCTOR
//==============================================================================
    /**
     * Constructor
     */
    public function BanClientWindow () {
      buildUI();
      showCloseButton = true;
      addEventListener(CloseEvent.CLOSE, closeClickListener);
      setStyle("borderAlpha", .9);
    }
    
//==============================================================================
// UI CREATION
//==============================================================================
    
    protected function buildUI ():void {
      banClientPane = new BanClientPane();
      addChild(banClientPane);
      this.width = 450;
      this.height = 150;
    }
    
//==============================================================================
// DEPENDENCIES
//==============================================================================
    
    /**
     * @private
     */    
    public function set client (value:IClient):void {
      banClientPane.client = value;
      title = "Ban Client ID ["
            + value.getClientID() + "]"
            + (value.getIP() != null ? " (IP Address: " + value.getIP() + ")" : "")
    }

    /**
     * The AccountManager object used to perform account registration attempts.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function get client ():IClient {
      return banClientPane.client;
    }
    
//==============================================================================
// UI CONTROL
//==============================================================================
    
    public function close ():void {
      dispose();
      PopUpManager.removePopUp(this);
    }
    
//==============================================================================
// UI Listeners
//==============================================================================
    
    public function closeClickListener (e:CloseEvent):void {
      close();
    }
    
//==============================================================================
// DISPOSAL
//==============================================================================
    
    /**
     * Disposes of the resources used by this object, preparing it for garbage
     * collection.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function dispose ():void {
      banClientPane.dispose();
    }
  }
}