package net.user1.reactor.ui {
  import mx.controls.Button;
  
  import net.user1.reactor.AccountEvent;
  import net.user1.reactor.chat.ChatClient;
  import net.user1.utils.EventUtil;
  
  /**
   * A "Send" button used to send chat messages in a chat interface.
   * 
   * @since ReactorGUI 1.0.0
   */
  public class ChatSendButton extends Button {
    protected var targetClient:ChatClient;
    
    public function ChatSendButton () {
      refresh();
    }
    
// =============================================================================    
//  DEPENDENCIES   
// =============================================================================    
    
    /**
     * @private
     */
    public function set client (value:ChatClient):void {
      EventUtil.migrateListeners(targetClient, value,
        [AccountEvent.LOGIN, loginListener]);
      targetClient = value;
      refresh();
    }
    
    /**
     * The ChatClient object representing the client that will receive the
     * chat message when this send button is clicked.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function get client ():ChatClient {
      return targetClient;
    }
    
// =============================================================================    
//  AccountEvent LISTENERS    
// =============================================================================    
    
    protected function loginListener (e:AccountEvent):void {
      refresh();
    }
    
// =============================================================================    
//  UI MANAGEMENT    
// =============================================================================
    
    protected function refresh ():void {
      if (targetClient == null) {
        label = "Send to Everyone";
      } else {
        if (targetClient.isSelf()) {
          label = "Send to Yourself";
        } else {
          label = "Send to " + targetClient.getUserName();
        }
      }
    }
  }
}