package net.user1.reactor.ui {
  import mx.controls.Label;
  
  import net.user1.reactor.ClientManager;
  import net.user1.reactor.ClientManagerEvent;
  import net.user1.utils.EventUtil;
  
  /**
   * Displays the number of clients currently connected to Union Server. Requires
   * the supplied ClientManager to watchForClients().
   * 
   * @since ReactorGUI 1.0.0
   */  
  public class ClientCount extends Label {
// =============================================================================
// VARIABLES
// =============================================================================
    public static var DEFAULT_LABEL:String = "Connected clients: ";
    private var _clientManager:ClientManager;
    private var _label:String = ClientCount.DEFAULT_LABEL;
    
// =============================================================================
// LABEL
// =============================================================================
    
    public function get label ():String {
      return _label;
    }

    public function set label (value:String):void {
      _label = value;
      refreshDisplay();
    }
    
// =============================================================================
// DEPENDENCIES
// =============================================================================
    
    /**
     * @private
     */
    public function set clientManager (value:ClientManager):void {
      EventUtil.migrateListeners(_clientManager, value,
        [ClientManagerEvent.CLIENT_CONNECTED, clientCountListener,
         ClientManagerEvent.CLIENT_DISCONNECTED, clientCountListener]);
      _clientManager = value;
      refreshDisplay();
    }
    
    /**
     * The ClientManager object for which this control
     * should display the number of clients.
     */
    public function get clientManager ():ClientManager {
      return _clientManager;
    }
    
// =============================================================================
// ClientManager LISTENERS
// =============================================================================
    
    /**
     * Listener triggered when the client manager's client count changes.
     */
    protected function clientCountListener (e:ClientManagerEvent):void {
      refreshDisplay();
    }
    
// =============================================================================
// UI CONTROL
// =============================================================================
    
    protected function refreshDisplay ():void {
      text = label + clientManager.getNumClientsOnServer();
    }
    
// =============================================================================
// DISPOSAL
// =============================================================================
    
    /**
     * Disposes of the resources used by this class, preparing it for garbage
     * collection.
     */
    protected function dispose ():void {
      _clientManager.removeEventListener(ClientManagerEvent.CLIENT_CONNECTED, clientCountListener);
      _clientManager.removeEventListener(ClientManagerEvent.CLIENT_DISCONNECTED, clientCountListener);
      
      _clientManager = null;
    }
  }
}