package net.user1.reactor.ui {
  import mx.containers.HBox;
  import mx.controls.Label;
  
  import net.user1.reactor.Reactor;
  import net.user1.reactor.ReactorEvent;
  import net.user1.utils.EventUtil;
  
  /**
   * Displays a connection status message and icon indicating whether 
   * Reactor is connected to the server.
   * 
   * @since ReactorGUI 1.0.0
   */
  public class ConnectionStatusPane extends HBox {
//==============================================================================
// VARIABLES
//==============================================================================
    private var _reactor:Reactor;
    
    private var connectedIcon:Orb;
    private var disconnectedIcon:Orb;
    
    private var status:Label;

//==============================================================================
// CONSTRUCTOR
//==============================================================================

    /**
     * Constructor
     */
    public function ConnectionStatusPane () {
      buildUI();
    }

//==============================================================================
// DEPENDENCIES
//==============================================================================
    
    /**
     * @private
     */
    public function set reactor (value:Reactor):void {
      EventUtil.migrateListeners(_reactor, value,
        [ReactorEvent.READY, connectionReadyListener,
         ReactorEvent.CLOSE, connectionCloseListener]);

      _reactor = value;
      refreshDisplay();
    }
    
    /**
     * The Reactor object for which this pane
     * should display connection status.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function get reactor ():Reactor {
      return _reactor;
    }

//==============================================================================
// UI MANAGEMENT
//==============================================================================
    
    /**
     * Creates the user interface.
     */ 
    protected function buildUI ():void {
      connectedIcon = new Orb(0xCCFFB7, 0xCAA200, 0xFFFFFF, 0x00CC00);
      disconnectedIcon = new Orb(0x7e674a, 0x50422f, 0x867841, 0x503e26);
      
      status = new Label();
      status.height = 15;  // Make the label shorter so it aligns with the icon
      
      setStyle("verticalAlign", "middle");

      addChild(status);
      addChild(connectedIcon);
      addChild(disconnectedIcon);
    }

    /**
     * Displays the current connection status.
     */
    protected function refreshDisplay ():void {
      // Add the appropriate connection icon
      if (_reactor != null && _reactor.isReady()) {
        connectedIcon.visible = true;
        connectedIcon.includeInLayout = true;
        disconnectedIcon.visible = false;
        disconnectedIcon.includeInLayout = false;
        status.text = "Connected";
      } else {
        connectedIcon.visible = false;
        connectedIcon.includeInLayout = false;
        disconnectedIcon.visible = true;
        disconnectedIcon.includeInLayout = true;
        status.text = "Not connected";
      }
    }

//==============================================================================
// REACTOREVENT LISTENERS
//==============================================================================

    /**
     * Listener triggered on connection ready.
     */
    protected function connectionReadyListener (e:ReactorEvent):void {
      refreshDisplay();
    }
    
    /**
     * Listener triggered when connection closes.
     */
    protected function connectionCloseListener (e:ReactorEvent):void {
      refreshDisplay();
    }

//==============================================================================
// DISPOSAL
//==============================================================================
    
    /**
     * Disposes of the resources used by this object, preparing it for garbage
     * collection.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function dispose ():void {
      if (_reactor != null) {
        _reactor.removeEventListener(ReactorEvent.READY, connectionReadyListener);
        _reactor.removeEventListener(ReactorEvent.CLOSE, connectionCloseListener);
      }
      
      _reactor = null;
    }
  }
}