package net.user1.reactor.ui {
  import flash.events.MouseEvent;
  
  import mx.containers.HDividedBox;
  import mx.containers.Panel;
  
  import net.user1.reactor.Reactor;
  
  /**
   * A debugging panel that displays log messages and statistics for
   * Reactor applications.
   * 
   * @since ReactorGUI 1.0.0
   */
  public class DebugPanel extends Panel {
//==============================================================================
// VARIABLES
//==============================================================================
    protected var content:HDividedBox;
    protected var logPane:LogPane;
    protected var statsPane:StatsPane;
    
//==============================================================================
// CONSTRUCTOR
//==============================================================================
    public function DebugPanel () {
      title = "Debugging";
      createChildren();
      setStyle("borderAlpha", .9);
    }
    
//==============================================================================
// DEPENDENCIES
//==============================================================================
    
    /**
     * The Reactor object for which this debug panel should display 
     * debugging information.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function setReactor (reactor:Reactor):void {
      logPane.setLog(reactor.getLog());
      statsPane.setReactor(reactor);
    }
    
//==============================================================================
// UI MANAGEMENT
//==============================================================================
    
    /**
     * UI Creation
     */
    override protected function createChildren ():void {
      super.createChildren();
      
      if (content == null) {
        content = new HDividedBox();
        content.percentWidth = 100;
        content.percentHeight = 100;
        
        logPane = new LogPane();
        logPane.percentWidth = 70;
        statsPane = new StatsPane();
        statsPane.percentWidth = 30;
        
        content.addChild(logPane);
        content.addChild(statsPane);
        addChild(content);
        
        super.titleBar.addEventListener(MouseEvent.MOUSE_DOWN, titleMouseDownListener);
        super.titleBar.addEventListener(MouseEvent.MOUSE_UP, titleMouseUpListener);
      }
    }

    private function titleMouseDownListener (e:MouseEvent):void{
      this.startDrag()
    }
    
    private function titleMouseUpListener (e:MouseEvent):void{
      this.stopDrag()
    }
    
//==============================================================================
// DISPOSAL
//==============================================================================
    
    /**
     * Disposes of the resources used by this object, preparing it for garbage
     * collection.
     * 
     * @ReactorGUI 1.0.0
     */    
    public function dispose ():void {
      logPane.dispose();
      statsPane.dispose();
    }
  }
}