package net.user1.reactor.ui {
  import flash.events.Event;
  import flash.text.TextFormat;
  
  import mx.controls.HScrollBar;
  import mx.controls.VScrollBar;
  import mx.core.UIComponent;
  import mx.events.ScrollEvent;
  
  /**
   * <p>
   * A high-performance text area for that adds scrollbars to FastTextField.
   * </p>
   * 
   * @since ReactorGUI 1.0.0
   * 
   * @see FastTextField
   */
  public class FastTextArea extends mx.core.UIComponent {
    
// =============================================================================
// VARIABLES
// =============================================================================
    protected var txt:FastTextField;
    protected var vscrollbar:VScrollBar;
    protected var hscrollbar:HScrollBar;
    protected var _autoScroll:Boolean;
    
// =============================================================================
// CONSTRUCTOR
// =============================================================================
    
    public function FastTextArea () {
      // Init vars
      txt = new FastTextField();
      vscrollbar = new VScrollBar();
      hscrollbar = new HScrollBar();
      
      // Add children
      addChild(txt);
      addChild(vscrollbar);
      addChild(hscrollbar);
      
      // Register listeners
      hscrollbar.addEventListener(ScrollEvent.SCROLL, hbarScrollListener);
      vscrollbar.addEventListener(ScrollEvent.SCROLL, vbarScrollListener);
      this.addEventListener(Event.ENTER_FRAME, enterFrameListener);
    }

// =============================================================================
// EVENT LISTENERS
// =============================================================================
    
    // Update scrollbars every frame
    protected function enterFrameListener (e:Event):void {
      // FastTextField's scrollV starts at 1, not 0, so subtract 1
      vscrollbar.maxScrollPosition = txt.maxScrollV-1;
      vscrollbar.pageSize          = txt.pageLineCount-1;
      vscrollbar.scrollPosition    = txt.scrollV-1;
      
      hscrollbar.maxScrollPosition = txt.maxScrollH;
      hscrollbar.pageSize          = txt.pageWidth;
      hscrollbar.scrollPosition    = txt.scrollH;
    }
    
    protected function vbarScrollListener (e:ScrollEvent):void {
      // FastTextField's scrollV starts at 1, not 0, so add 1
      txt.scrollV = vscrollbar.scrollPosition+1;
      if (vscrollbar.scrollPosition != vscrollbar.maxScrollPosition) {
        txt.autoScroll = false;
      } else {
        if (autoScroll) {
          txt.autoScroll = true;
        }
      }
    }
    
    protected function hbarScrollListener (e:ScrollEvent):void {
      txt.scrollH = hscrollbar.scrollPosition;
    }
    
// =============================================================================
// TEXT MANAGEMENT
// =============================================================================
    
    public function set text (text:String):void {
      txt.text = text;
    }
    
    public function appendText (text:String, color:Object=null):void {
      txt.appendText(text, color);
    }
    
// =============================================================================
// UICOMPONENT OVERRIDES
// =============================================================================
    
    override protected function measure ():void {
      super.measure();
      
      measuredWidth = 400;
      measuredHeight = 150;
      measuredMinWidth = 200;
      measuredMinHeight = 100;
    }
    
    override protected function updateDisplayList (unscaledWidth:Number,
                                                   unscaledHeight:Number):void {
      super.updateDisplayList(unscaledWidth, unscaledHeight);
      setActualSize(unscaledWidth, unscaledHeight);
      txt.width = unscaledWidth-vscrollbar.getExplicitOrMeasuredWidth();
      txt.height = unscaledHeight-hscrollbar.getExplicitOrMeasuredHeight();
      vscrollbar.move(unscaledWidth-vscrollbar.getExplicitOrMeasuredWidth()/2, vscrollbar.y);
      vscrollbar.height = unscaledHeight-hscrollbar.getExplicitOrMeasuredHeight();
      hscrollbar.move(hscrollbar.x, unscaledHeight-hscrollbar.getExplicitOrMeasuredHeight()/2);
      hscrollbar.width = unscaledWidth-vscrollbar.getExplicitOrMeasuredWidth();
    }

// =============================================================================
// CLIPBOARD
// =============================================================================
    
    public function copyToClipboard ():void {
      txt.copyToClipboard();
    }
    
// =============================================================================
// SETTINGS AND METRICS
// =============================================================================
    
    public function get backgroundColor():uint {
      return txt.backgroundColor;
    }

    public function set backgroundColor(value:uint):void {
      txt.backgroundColor = value;
    }

    public function get backgroundAlpha():Number {
      return txt.backgroundAlpha;
    }

    public function set backgroundAlpha(value:Number):void {
      txt.backgroundAlpha = value;
    }

    public function get borderColor():uint {
      return txt.borderColor;
    }

    public function set borderColor(value:uint):void {
      txt.borderColor = value;
    }

    public function get borderAlpha():Number {
      return txt.borderAlpha;
    }

    public function set borderAlpha(value:Number):void {
      txt.borderAlpha = value;
    }

    public function get borderThickness():Number {
      return txt.borderThickness;
    }

    public function set borderThickness(value:Number):void {
      txt.borderThickness = value;
    }

    public function get scrollV ():int {
      return txt.scrollV;
    }

    public function set scrollV (value:int):void {
      txt.scrollV = value;
    }

    public function get scrollH ():int {
      return txt.scrollH;
    }

    public function set scrollH (value:int):void {
      txt.scrollH = value;
    }

    public function get maxScrollV ():int {
      return txt.maxScrollV;
    }

    public function get maxScrollH ():int {
      return txt.maxScrollH;
    }

    public function get autoScroll ():Boolean {
      return _autoScroll;
    }

    public function set autoScroll (value:Boolean):void {
      txt.autoScroll = value;
      _autoScroll = value;
    }

    public function get maxLength ():int {
      return txt.maxLength;
    }

    public function set maxLength (value:int):void {
      txt.maxLength = value;
    }
    
    public function get pageLineCount ():int {
      return txt.pageLineCount;
    }

    public function get pageWidth ():int {
      return txt.pageWidth;
    }

    public function set textFormat (value:TextFormat):void {
      txt.setTextFormat(value);
    }
    

// =============================================================================
// DISPOSAL
// =============================================================================
    
    protected function dispose ():void {
      vscrollbar.removeEventListener(ScrollEvent.SCROLL, vbarScrollListener);
      hscrollbar.removeEventListener(ScrollEvent.SCROLL, hbarScrollListener);
      removeEventListener(Event.ENTER_FRAME, enterFrameListener);
    }
  }
}