package net.user1.reactor.ui {
  import mx.containers.VBox;
  
  import net.user1.logger.LogEvent;
  import net.user1.logger.Logger;
  import net.user1.utils.EventUtil;
  
  /**
   * Displays Reactor log messages in an auto-scrolling text field.
   * 
   * @since ReactorGUI
   * 
   * @see DebugPanel
   */
  public class LogPane extends VBox {
// =============================================================================
// VARIABLES
// =============================================================================
    private var log:Logger;
    private var maxChars:int = 10000;
    private var logOutput:AutoScrollTextArea;
    
// =============================================================================
// CONSTRUCTOR
// =============================================================================      
    public function LogPane () {
      percentWidth = 100;
      percentHeight = 100;
    }

// =============================================================================
// DEPENDENCIES
// =============================================================================
    /**
     * Specifies the Logger object whose messages this LogPane will display
     * 
     * @since ReactorGUI 1.0.0
     */
    public function setLog (log:Logger):void {
      var history:Array;
      // Migrate listeners
      EventUtil.migrateListeners(this.log, log,
        [LogEvent.UPDATE, logListener]);
      this.log = log;

      // Print out the log's history
      history = log.getHistory();
      for each (var entry:String in history) {
        logOutput.text += entry + "\n";
      }
    }
    
// =============================================================================
// LOGEVENT LISTENERS
// =============================================================================
    
    /**
     * Triggered when a log message is added to the log.
     */ 
    private function logListener (e:LogEvent):void {
      displayLogEntry(e.getTimeStamp(), e.getLevel(), e.getMessage());
    }
    
// =============================================================================
// UI MANAGEMENT
// =============================================================================
    
    protected function displayLogEntry (time:String, level:String, msg:String):void {
      logOutput.appendText(time + " " + level + ": " + msg + "\n");
    }
    
    override protected function createChildren ():void {
      super.createChildren();
      if (logOutput == null) {
        logOutput = new AutoScrollTextArea();
        logOutput.percentWidth = 100;
        logOutput.percentHeight = 100;
        logOutput.maxLength = 100000;
        
        addChild(logOutput);
      }
    }
    
// =============================================================================
// DISPOSAL
// =============================================================================

    /**
     * Disposes of the resources used by this object, preparing it for garbage
     * collection.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function dispose ():void {
      if (log) {
        log.removeEventListener(LogEvent.UPDATE, logListener);
      }
      log = null;
    }
  }
}