package net.user1.reactor.ui {
  import flash.events.TimerEvent;
  import flash.utils.Timer;
  
  import mx.controls.Label;
  
  import net.user1.reactor.AccountManager;
  
  /**
   * Displays the number of user accounts currently known to be logged in
   * by Reactor.
   * 
   * See AccountManager's getNumLoggedInAccounts() method.
   * 
   * @since ReactorGUI 1.0.0
   */
  public class LoggedInCount extends Label {
// =============================================================================
// VARIABLES
// =============================================================================
    public static var DEFAULT_LABEL:String = "Logged in: ";
    private var _accountManager:AccountManager;
    private var _label:String = LoggedInCount.DEFAULT_LABEL;
    private var refreshTimer:Timer;
    
// =============================================================================
// CONSTRUCTOR
// =============================================================================
    
    public function LoggedInCount () {
      refreshTimer = new Timer(5000);
      refreshTimer.addEventListener(TimerEvent.TIMER, refreshTimerListener);
      refreshTimer.start();
    }
    
// =============================================================================
// REFRESH TIMER
// =============================================================================

    protected function refreshTimerListener (e:TimerEvent):void {
      refreshDisplay();
    }
    
// =============================================================================
// LABEL
// =============================================================================
    
    public function get label ():String {
      return _label;
    }

    public function set label (value:String):void {
      _label = value;
      refreshDisplay();
    }
    
// =============================================================================
// DEPENDENCIES
// =============================================================================
    
    /**
     * @private
     */
    public function set accountManager (value:AccountManager):void {
      _accountManager = value;
      refreshDisplay();
    }
    
    /**
     * The AccountManager object for which this control
     * should display the number of user accounts.
     */
    public function get accountManager ():AccountManager {
      return _accountManager;
    }
    
// =============================================================================
// UI CONTROL
// =============================================================================
    
    protected function refreshDisplay ():void {
      var count:int = 0;
      if (accountManager != null) {
        count = accountManager.getNumLoggedInAccounts();
      }
      text = label + count;
    }
    
// =============================================================================
// DISPOSAL
// =============================================================================
    
    /**
     * Disposes of the resources used by this class, preparing it for garbage
     * collection.
     */
    protected function dispose ():void {
      _accountManager = null;
      refreshTimer.stop();
      refreshTimer.removeEventListener(TimerEvent.TIMER, refreshTimerListener);
      refreshTimer = null;
    }
  }
}