package net.user1.reactor.ui {
  import mx.containers.TitleWindow;
  import mx.events.CloseEvent;
  import mx.managers.PopUpManager;
  
  import net.user1.reactor.AccountEvent;
  import net.user1.reactor.AccountManager;

  /**
   * A popup window containing a login interface.
   * 
   * @ReactorGUI 1.0.0
   * 
   * @see LoginPane
   */
  public class LoginWindow extends TitleWindow {
//==============================================================================
// VARIABLES
//==============================================================================
    protected var loginPane:LoginPane;
    protected var _accountManager:AccountManager;
    
//==============================================================================
// CONSTRUCTOR
//==============================================================================
    /**
     * Constructor
     */
    public function LoginWindow () {
      buildUI();
      title = "Union Login";
      showCloseButton = true;
      addEventListener(CloseEvent.CLOSE, closeClickListener);
    }

//==============================================================================
// UI CREATION
//==============================================================================
    protected function buildUI ():void {
      loginPane = new LoginPane();
      addChild(loginPane);
    }

//==============================================================================
// DEPENDENCIES
//==============================================================================
    
    /**
     * @private
     */
    public function set accountManager (value:AccountManager):void {
      if (_accountManager != null) {
        _accountManager.removeEventListener(AccountEvent.LOGIN, loginListener);
      }
      _accountManager = value;
      
      if (_accountManager != null) {
        _accountManager.addEventListener(AccountEvent.LOGIN, loginListener);
        if (_accountManager.selfAccount() != null
           && !_accountManager.selfAccount().isLoggedIn()) {
          loginPane.focusUserID();
        }
      }
      loginPane.accountManager = value;
    }

    /**
     * The AccountManager object for this LoginWindow.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function get accountManager ():AccountManager {
      return _accountManager;
    }
    
//==============================================================================
// UI CONTROL
//==============================================================================
    
    /**
     * Closes this popup window.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function close ():void {
      dispose();
      PopUpManager.removePopUp(this);
    }
    
//==============================================================================
// UI Listeners
//==============================================================================
    
    protected function closeClickListener (e:CloseEvent):void {
      close();
    }
    
//==============================================================================
// AccountEvent LISTENERS
//==============================================================================
    
    protected function loginListener (e:AccountEvent):void {
      if (e.getAccount().isSelf()) {
        accountManager.removeEventListener(AccountEvent.LOGIN, loginListener);
        close();
      }
    } 
    
//==============================================================================
// DISPOSAL
//==============================================================================

    /**
     * Disposes of the resources used by this object, preparing it for garbage
     * collection.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function dispose ():void {
      _accountManager.removeEventListener(AccountEvent.LOGIN, loginListener);
      loginPane.dispose();
    }
  }
}