package net.user1.reactor.ui {
  import flash.events.Event;
  
  import mx.containers.TitleWindow;
  import mx.events.CloseEvent;
  import mx.managers.PopUpManager;
  
  import net.user1.reactor.AccountManager;
  import net.user1.reactor.AccountManagerEvent;
  
  /**
   * A popup window containing a user-account registration interface.
   * 
   * @ReactorGUI 1.0.0
   * 
   * @see RegisterPane
   */
  public class RegisterWindow extends TitleWindow {
//==============================================================================
// VARIABLES
//==============================================================================
    protected var registerPane:RegisterPane;
    
//==============================================================================
// CONSTRUCTOR
//==============================================================================
    /**
     * Constructor
     */
    public function RegisterWindow () {
      buildUI();
      title = "Register Union Account";
      showCloseButton = true;
      addEventListener(CloseEvent.CLOSE, closeClickListener);
      addEventListener(Event.ADDED_TO_STAGE, addedToStageListener);
    }
    
//==============================================================================
// UI CREATION
//==============================================================================
    
    protected function buildUI ():void {
      registerPane = new RegisterPane();
      addChild(registerPane);
    }
    
//==============================================================================
// DEPENDENCIES
//==============================================================================
    
    /**
     * @private
     */    
    public function set accountManager (value:AccountManager):void {
      registerPane.accountManager = value;
    }

    /**
     * The AccountManager object used to perform account registration attempts.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function get accountManager ():AccountManager {
      return registerPane.accountManager;
    }
    
//==============================================================================
// UI CONTROL
//==============================================================================
    
    public function close ():void {
      dispose();
      PopUpManager.removePopUp(this);
    }
    
//==============================================================================
// UI Listeners
//==============================================================================
    
    public function closeClickListener (e:CloseEvent):void {
      close();
    }
    
    public function addedToStageListener (e:Event):void {
      registerPane.focusUserID();
    }
    
//==============================================================================
// DISPOSAL
//==============================================================================
    
    /**
     * Disposes of the resources used by this object, preparing it for garbage
     * collection.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function dispose ():void {
      registerPane.dispose();
      removeEventListener(Event.ADDED_TO_STAGE, addedToStageListener);
    }
  }
}