package net.user1.reactor.ui {
  import mx.controls.Label;
  
  import net.user1.reactor.RoomManager;
  import net.user1.reactor.RoomManagerEvent;
  import net.user1.utils.EventUtil;
  
  /**
   * A Label that shows the number of rooms with a given qualifier currently
   * in the specified RoomManager's room list.
   * 
   * @since ReactorGUI 1.0.0
   */  
  public class RoomCount extends Label {
// =============================================================================
// VARIABLES
// =============================================================================
    public static var DEFAULT_LABEL:String = "Total Rooms: ";
    private var _roomManager:RoomManager;
    private var _label:String = RoomCount.DEFAULT_LABEL;
    private var _qualifier:String;
    
// =============================================================================
// LABEL
// =============================================================================
    
    public function get label ():String {
      return _label;
    }

    public function set label (value:String):void {
      _label = value;
      refreshDisplay();
    }
    
// =============================================================================
// QUALIFIER
// =============================================================================
    /**
     * @private
     */    
    public function set qualifier (value:String):void {
      _qualifier = value;
      refreshDisplay();
    }
    
    /**
     * Specifies the qualifer for which this control should display the room
     * count.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function get qualifier ():String {
      return _qualifier;
    }
    
// =============================================================================
// DEPENDENCIES
// =============================================================================
    
    /**
     * @private
     */
    public function set roomManager (value:RoomManager):void {
      EventUtil.migrateListeners(_roomManager, value,
        [RoomManagerEvent.ROOM_COUNT, roomCountListener]);
      _roomManager = value;
      refreshDisplay();
    }
    
    /**
     * The RoomManager object for which this control
     * should display a room count.
     * 
     * @sionce ReactorGUI 1.0.0
     */
    public function get roomManager ():RoomManager {
      return _roomManager;
    }
    
// =============================================================================
// ROOM MANAGER LISTENERS
// =============================================================================
    
    /**
     * Listener triggered when the room manager's room count changes.
     */
    protected function roomCountListener (e:RoomManagerEvent):void {
      refreshDisplay();
    }
    
// =============================================================================
// UI CONTROL
// =============================================================================
    
    /**
     * Displays the current number of rooms.
     */
    protected function refreshDisplay ():void {
      text = label + roomManager.getNumRooms(qualifier);
    }
    
// =============================================================================
// DISPOSAL
// =============================================================================
    
    /**
     * Disposes of the resources used by this class, preparing it for garbage
     * collection.
     */
    protected function dispose ():void {
      if (_roomManager != null) {
        _roomManager.removeEventListener(RoomManagerEvent.ROOM_COUNT, roomCountListener);
      }
      
      _roomManager = null;
    }
  }
}