package net.user1.reactor.ui {
  import net.user1.reactor.Room;
  import net.user1.reactor.RoomEvent;
  import net.user1.utils.EventUtil;
  
  /**
   * A List component that displays the clients in a given room. For 
   * clients that are registered and logged in, the RoomOccupantList displays 
   * user IDs. For other clients, the RoomOccupantList displays the string 
   * "User" plus the client's client ID (e.g., "User1", "User2", "User3", etc).
   * 
   * @since ReactorGUI 1.0.0
   */
  public class RoomOccupantList extends RoomClientList {
    override protected function migrateListeners (oldRoom:Room, newRoom:Room):void {
      super.migrateListeners(oldRoom, newRoom);
      EventUtil.migrateListeners(oldRoom, newRoom,
        [RoomEvent.ADD_OCCUPANT, addClientListener,
         RoomEvent.REMOVE_OCCUPANT, removeClientListener]);
    }
    
    override protected function disposeListeners ():void {
      super.disposeListeners();
      _room.removeEventListener(RoomEvent.ADD_OCCUPANT, addClientListener);
      _room.removeEventListener(RoomEvent.REMOVE_OCCUPANT, removeClientListener);
    }
    
    override protected function getClients ():Array {
      return _room.getOccupants();
    }
  }
}
