package net.user1.reactor.ui {
  import flash.events.*;
  
  /**  
   * TextInputWindowEvent is a simple data class used to pass information from 
   * a TextInputWindow object to registered event-listeners when
   * a TextInputWindow event occurs. 
   * 
   * The TextInputWindowEvent class also defines constants representing the 
   * available TextInputWindow events.
   * 
   * Since 
   * ReactorGUI 1.0.0
   */
  public class TextInputWindowEvent extends Event {
// =============================================================================
// VARIABLES
// =============================================================================
    /**
     * Triggered when input in a TextInputWindow is submitted via the 
     * OK button or the Enter key.
     *
     * @since ReactorGUI 1.0.0
     */ 
    public static const SUBMIT:String = "SUBMIT";
    
    private var input:String;
  
// =============================================================================
// CONSTRUCTOR
// =============================================================================
    public function TextInputWindowEvent (type:String,
                                          bubbles:Boolean = false, 
                                          cancelable:Boolean = false,
                                          input:String = null) {
      super(type, bubbles, cancelable);
      this.input = input;
    }

// =============================================================================
// DATA ACCESS
// =============================================================================
    /**
     * Returns the input that was submitted via the TextInputWindow's
     * text input field.
     * 
     * @since ReactorGUI 1.0.0
     */
    public function getInput ():String {
      return input;
    }

// =============================================================================
// OVERRIDES
// =============================================================================

    public override function clone():Event {
      return new TextInputWindowEvent(type, bubbles, cancelable, input);
    }

    public override function toString ():String {
      return formatToString("TextInputWindowEvent", "type", "bubbles",
                            "cancelable", "eventPhase");
    }  
  }
}