package net.user1.reactor.ui {
  import mx.controls.Label;
  
  import net.user1.reactor.AccountManager;
  import net.user1.reactor.AccountManagerEvent;
  import net.user1.utils.EventUtil;
  

  /**
   * Displays the number of accounts currently registered on Union Server. 
   * Requires the supplied AccountManager to watchForAccounts().
   * 
   * @since ReactorGUI 1.0.0
   */  
  public class UserAccountCount extends Label {
// =============================================================================
// VARIABLES
// =============================================================================
    public static var DEFAULT_LABEL:String = "User accounts: ";
    private var _accountManager:AccountManager;
    private var _label:String = UserAccountCount.DEFAULT_LABEL;
    
// =============================================================================
// LABEL
// =============================================================================
    
    public function get label ():String {
      return _label;
    }

    public function set label (value:String):void {
      _label = value;
      refreshDisplay();
    }
    
// =============================================================================
// DEPENDENCIES
// =============================================================================
    
    /**
     * @private
     */
    public function set accountManager (value:AccountManager):void {
      EventUtil.migrateListeners(_accountManager, value,
        [AccountManagerEvent.ACCOUNT_ADDED, userAccountCountListener,
         AccountManagerEvent.ACCOUNT_REMOVED, userAccountCountListener]);
      _accountManager = value;
      refreshDisplay();
    }
    
    /**
     * The AccountManager object for which this control
     * should display the number of user accounts.
     */
    public function get accountManager ():AccountManager {
      return _accountManager;
    }
    
// =============================================================================
// AccountManager LISTENERS
// =============================================================================
    
    /**
     * Listener triggered when the account manager's user account count changes.
     */
    protected function userAccountCountListener (e:AccountManagerEvent):void {
      refreshDisplay();
    }
    
// =============================================================================
// UI CONTROL
// =============================================================================
    
    protected function refreshDisplay ():void {
      text = label + accountManager.getNumAccountsOnServer();
    }
    
// =============================================================================
// DISPOSAL
// =============================================================================
    
    /**
     * Disposes of the resources used by this class, preparing it for garbage
     * collection.
     */
    protected function dispose ():void {
      _accountManager.removeEventListener(AccountManagerEvent.ACCOUNT_ADDED, userAccountCountListener);
      _accountManager.removeEventListener(AccountManagerEvent.ACCOUNT_REMOVED, userAccountCountListener);
      
      _accountManager = null;
    }
  }
}