package net.user1.utils {
  import flash.display.BitmapData;
  import flash.display.DisplayObject;
  import flash.display.DisplayObjectContainer;
  import flash.geom.ColorTransform;
  import flash.geom.Rectangle;
  import flash.geom.Point;
  
  /**
   * Utilities for working with DisplayObject instances.
   * 
   * @since ReactorGUI 1.0
   */
  public final class DisplayObjectUtil {
    
    /**
     * Returns the distance from the registration point of the specified 
     * object to the bottom-most visible pixel, ignoring any region
     * that is not visible due to masking. For example, if a display
     * object contains a 100-pixel-high shape and a 50-pixel-high mask,
     * getVisibleHeight() will return 50, whereas DisplayObject's
     * "height" variable would yield 100. 
     * 
     * <p>
     * The maximum measureable dimensions of the supplied object is
     * 2000x2000.
     * </p>
     * 
     * @since ReactorGUI 1.0
     */
    public static function getVisibleHeight (o:DisplayObject):Number {
      var bitmapDataSize:int = 2000;
      var bounds:Rectangle;
      var bitmapData:BitmapData = new BitmapData(bitmapDataSize, 
                                                 bitmapDataSize,
                                                 true,
                                                 0);
      bitmapData.draw(o);
      bounds = bitmapData.getColorBoundsRect( 0xFF000000, 0x00000000, false );
      bitmapData.dispose(); 
      return bounds.y + bounds.height;
    }

    /**
     * Returns the distance from the registration point of the specified 
     * object to the right-most visible pixel, ignoring any region
     * that is not visible due to masking. For example, if a display
     * object contains a 100-pixel-wide shape and a 50-pixel-wide mask,
     * getVisibleWidth() will return 50, whereas DisplayObject's
     * "width" variable would yield 100. 
     * 
     * <p>
     * The maximum measureable dimensions of the supplied object is
     * 2000x2000.
     * </p>
     * 
     * @since ReactorGUI 1.0
     * 
     * @since MegaPhone App Framework 1.0
     */
    public static function getVisibleWidth (o:DisplayObject):Number {
      var bitmapDataSize:int = 2000;
      var bounds:Rectangle;
      var bitmapData:BitmapData = new BitmapData(bitmapDataSize, 
                                                 bitmapDataSize, 
                                                 true, 
                                                 0);
      bitmapData.draw(o);
      bounds = bitmapData.getColorBoundsRect( 0xFF000000, 0x00000000, false );
      bitmapData.dispose(); 
      return bounds.x + bounds.width;
    }

    /**
     * Removes all children of parent that match the specified type.
     * 
     * @since ReactorGUI 1.0
     */
    public static function removeChildrenByType (parent:DisplayObjectContainer,
                                                 type:Class):DisplayObject {
      var child:DisplayObject;
      for (var i:int = parent.numChildren; --i >= 0;) {
        child = parent.getChildAt(i);
        if (child is type) {
          return parent.removeChild(child);
        }
      }
      
      return null;
    }
  }
}